| Title: | Multi-Visit Closed Population Mark-Recapture Estimates |
|---|---|
| Description: | Compute bootstrap confidence intervals for the adjusted Schnabel and Schumacher-Eschmeyer multi-visit mark-recapture estimators based on Dettloff (2023) <doi:10.1016/j.fishres.2023.106756>. |
| Authors: | Kyle Dettloff [aut, cre, cph] |
| Maintainer: | Kyle Dettloff <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-23 08:56:00 UTC |
| Source: | https://github.com/k-dettloff/mrc |
Calculate adjusted Schnabel and Schumacher-Eschmeyer estimates with confidence intervals.
closedCI( marked, caught, recaptured, newmarks = NULL, alpha = 0.05, ndraws = 1e+05 )closedCI( marked, caught, recaptured, newmarks = NULL, alpha = 0.05, ndraws = 1e+05 )
marked |
number of animals marked on first visit ( |
caught |
vector of catch on subsequent visits ( |
recaptured |
vector of recaptures on subsequent visits ( |
newmarks |
vector of newly marked animals on subsequent visits (default: |
alpha |
type I error rate for confidence intervals (default: 0.05) |
ndraws |
number of bootstrap draws (default: 100,000) |
Bias adjusted estimators are based on Dettloff (2023).
Bootstrap confidence intervals are computed using a beta-binomial distribution with
n = nk, alpha = mk, and beta = nk - mk.
Matrix containing population size estimates with confidence intervals for each method.
Dettloff, K. (2023). Assessment of bias and precision among simple closed population mark-recapture estimators. Fisheries Research, 265, 106756. doi:10.1016/j.fishres.2023.106756
M2 <- 2 n <- c(232, 524, 152, 98, 353) m <- c(0, 5, 8, 6, 13) set.seed(123) closedCI(M2, n, m, ndraws = 10000)M2 <- 2 n <- c(232, 524, 152, 98, 353) m <- c(0, 5, 8, 6, 13) set.seed(123) closedCI(M2, n, m, ndraws = 10000)