| Type: | Package |
| Title: | Multi-Visit Closed Population Mark-Recapture Estimates |
| Version: | 0.1.1 |
| Date: | 2026-03-23 |
| Description: | Compute bootstrap confidence intervals for the adjusted Schnabel and Schumacher-Eschmeyer multi-visit mark-recapture estimators based on Dettloff (2023) <doi:10.1016/j.fishres.2023.106756>. |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| Imports: | stats |
| URL: | https://github.com/k-dettloff/mRc |
| BugReports: | https://github.com/k-dettloff/mRc/issues |
| NeedsCompilation: | no |
| Packaged: | 2026-03-23 23:44:26 UTC; kyle.dettloff |
| Author: | Kyle Dettloff [aut, cre, cph] |
| Maintainer: | Kyle Dettloff <kyle.dettloff@noaa.gov> |
| Repository: | CRAN |
| Date/Publication: | 2026-03-24 00:00:02 UTC |
Multi-visit closed population mark-recapture estimates
Description
Calculate adjusted Schnabel and Schumacher-Eschmeyer estimates with confidence intervals.
Usage
closedCI(
marked,
caught,
recaptured,
newmarks = NULL,
alpha = 0.05,
ndraws = 1e+05
)
Arguments
marked |
number of animals marked on first visit ( |
caught |
vector of catch on subsequent visits ( |
recaptured |
vector of recaptures on subsequent visits ( |
newmarks |
vector of newly marked animals on subsequent visits (default: |
alpha |
type I error rate for confidence intervals (default: 0.05) |
ndraws |
number of bootstrap draws (default: 10,000) |
Details
Bias adjusted estimators are based on Dettloff (2023).
Bootstrap confidence intervals are computed using a beta-binomial distribution with
n = nk, alpha = mk, and beta = nk - mk.
Value
Matrix containing population size estimates with confidence intervals for each method.
References
Dettloff, K. (2023). Assessment of bias and precision among simple closed population mark-recapture estimators. Fisheries Research, 265, 106756. doi:10.1016/j.fishres.2023.106756
Examples
M2 <- 2
n <- c(232, 524, 152, 98, 353)
m <- c(0, 5, 8, 6, 13)
set.seed(123)
closedCI(M2, n, m, ndraws = 1000)